@@ -120,7 +120,7 @@ define([
         }
         this.notebooks_list = [];
         this.sessions = {};
-        this.base_url_prefix = options.base_url_prefix;
+        this.nbclassic_path = options.nbclassic_path;
         this.base_url = options.base_url || utils.get_body_data("baseUrl");
         this.notebook_path = options.notebook_path || utils.get_body_data("notebookPath");
         this.initial_notebook_path = this.notebook_path;
@@ -171,7 +171,7 @@ define([
                 var w = window.open('', IPython._target);
                 that.contents.new_untitled(that.notebook_path || '', {type: 'file', ext: '.txt'}).then(function(data) {
                     w.location = utils.url_path_join(
-                        that.base_url_prefix, that.base_url, 'edit',
+                        that.base_url, that.nbclassic_path, 'edit',
                         utils.encode_uri_components(data.path)
                     );
                 }).catch(function (e) {
@@ -385,7 +385,7 @@ define([
         var breadcrumb = $('.breadcrumb');
         breadcrumb.empty();
         var list_item = $('<li/>');
-        var root_url = utils.url_path_join(that.base_url_prefix, that.base_url, '/tree');
+        var root_url = utils.url_path_join(that.base_url, that.nbclassic_path, '/tree');
         var root = $('<li/>').append(
             $("<a/>")
             .attr('href', root_url)
@@ -403,7 +403,7 @@ define([
                 window.history.pushState(
                     {path: path},
                     'Home',
-                    utils.url_path_join(that.base_url_prefix, that.base_url, 'tree')
+                    utils.url_path_join(that.base_url, that.nbclassic_path, 'tree')
                 );
                 that.update_location(path);
                 return false;
@@ -415,8 +415,8 @@ define([
             path_parts.push(path_part);
             var path = path_parts.join('/');
             var url = utils.url_path_join(
-                that.base_url_prefix,
                 that.base_url,
+                that.nbclassic_path,
                 '/tree',
                 utils.encode_uri_components(path)
             );
@@ -907,8 +907,8 @@ define([
         var link = item.find("a.item_link")
             .attr('href',
                 utils.url_path_join(
-                    this.base_url_prefix,
                     this.base_url,
+                    this.nbclassic_path,
                     uri_prefix,
                     utils.encode_uri_components(model.path)
                 )
@@ -931,8 +931,8 @@ define([
                 window.history.pushState({
                     path: model.path
                 }, model.path, utils.url_path_join(
-                    that.base_url_prefix,
                     that.base_url,
+                    that.nbclassic_path,
                     'tree',
                     utils.encode_uri_components(model.path)
                 ));
